==> haskell-wai-middleware-static-0.8.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.1
id: wai-middleware-static-0.8.1-JTW9ODvpp2CCDm4j8ETuP3
key: wai-middleware-static-0.8.1-JTW9ODvpp2CCDm4j8ETuP3
license: BSD3
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
author: Andrew Farmer <afarmer@ittc.ku.edu>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Middleware.Static
abi: c360d136d02e15832c98681652bcd8a0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-middleware-static-0.8.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-middleware-static-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-middleware-static-0.8.1
hs-libraries: HSwai-middleware-static-0.8.1-JTW9ODvpp2CCDm4j8ETuP3
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    cryptonite-0.24-FsGdn9UZ3LaKB1k22FpT6O
    memory-0.14.11-3SpbaRkSFfh8uo9jYloypK directory-1.3.0.2
    expiring-cache-map-0.0.6.1-1sfnXkg4JVCFBAAfayxWz6 filepath-1.4.1.2
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
    mime-types-0.1.0.7-FBTbThCZY4IAxCrf9Kjzw3
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    wai-3.2.1.1-7dN2HoiA0i33RmBsF3iVOX
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-FsGdn9UZ3LaKB1k22FpT6O=2a2c063fe509f8391029ab6415e03b56
             memory-0.14.11-3SpbaRkSFfh8uo9jYloypK=4e89c83af85871b8cc7efa88b3351f52
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             expiring-cache-map-0.0.6.1-1sfnXkg4JVCFBAAfayxWz6=dfc6822592d647beb2c700fcb45101d1
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
             mime-types-0.1.0.7-FBTbThCZY4IAxCrf9Kjzw3=876b8a8b9446742c5332d5115f2c1813
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             wai-3.2.1.1-7dN2HoiA0i33RmBsF3iVOX=3e93ed1725445221ad4eb8227167be39
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.8.1-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.1
id: wai-middleware-static-0.8.1-BWMQqQs2Xx5IfYXONOeto7
key: wai-middleware-static-0.8.1-BWMQqQs2Xx5IfYXONOeto7
license: BSD3
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
author: Andrew Farmer <afarmer@ittc.ku.edu>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Middleware.Static
abi: 7c183817b07f6565d6875988ff146ddd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-middleware-static-0.8.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-middleware-static-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-middleware-static-0.8.1
hs-libraries: HSwai-middleware-static-0.8.1-BWMQqQs2Xx5IfYXONOeto7
depends:
    base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx
    memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b directory-1.3.0.2
    expiring-cache-map-0.0.6.1-1sfnXkg4JVCFBAAfayxWz6 filepath-1.4.1.2
    http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv
    mime-types-0.1.0.7-FBTbThCZY4IAxCrf9Kjzw3
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx=f485729293cc44bcb426ebfe7176782a
             memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b=31288e97a1618db31ba2d3698d738018
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             expiring-cache-map-0.0.6.1-1sfnXkg4JVCFBAAfayxWz6=dfc6822592d647beb2c700fcb45101d1
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             http-types-0.9.1-4ZIPDJugy3GJAtyWZ0RpKv=b80836ab18bdd54a07dfb2450d10ef5b
             mime-types-0.1.0.7-FBTbThCZY4IAxCrf9Kjzw3=876b8a8b9446742c5332d5115f2c1813
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             wai-3.2.1.1-12WuVnNjQfQ3f2A19Ra0dE=73d1afed3c80663ac957a99a7f1e4642
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
